#
# spec file for package btrfsmaintenance
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           btrfsmaintenance
VCS: https://src.suse.de/SLFO-pool/btrfsmaintenance#eab1857ec12a6e98214945d3e206bfc99e502fb6154b46f8ac06de837ddfef24
Version:        0.5
Release:        slfo.1.1_1.2
Summary:        Scripts for btrfs periodic maintenance tasks
License:        GPL-2.0-only
Group:          System/Base
URL:            https://github.com/kdave/btrfsmaintenance
Source0:        %{name}-%{version}.tar.bz2
Source1:        btrfs-defrag-plugin.sh
BuildRequires:  pkgconfig(systemd)
Requires:       btrfsprogs
Requires:       (libzypp(plugin:commit) if zypper)
Supplements:    btrfsprogs
BuildArch:      noarch
%{?systemd_ordering}

%description
Scripts for btrfs maintenance tasks like periodic scrub, balance, trim or defrag
on selected mountpoints or directories. Hints for periodic snapshot tuning (eg.
for snapper).

%prep
%setup -q
cp %{SOURCE1} .

%build

%install
# scripts
install -m 755 -d %{buildroot}%{_datadir}/%{name}
install -m 755 btrfs-defrag.sh %{buildroot}%{_datadir}/%{name}
install -m 755 btrfs-balance.sh %{buildroot}%{_datadir}/%{name}
install -m 755 btrfs-scrub.sh %{buildroot}%{_datadir}/%{name}
install -m 755 btrfs-trim.sh %{buildroot}%{_datadir}/%{name}
install -m 755 btrfsmaintenance-refresh-cron.sh %{buildroot}%{_datadir}/%{name}
install -m 644 btrfsmaintenance-functions %{buildroot}%{_datadir}/%{name}

# systemd services and timers
install -m 755 -d %{buildroot}%{_unitdir}
install -m 644 -D btrfsmaintenance-refresh.service %{buildroot}%{_unitdir}
install -m 644 -D btrfsmaintenance-refresh.path %{buildroot}%{_unitdir}
install -m 644 -D btrfs-balance.service %{buildroot}%{_unitdir}
install -m 644 -D btrfs-defrag.service %{buildroot}%{_unitdir}
install -m 644 -D btrfs-scrub.service %{buildroot}%{_unitdir}
install -m 644 -D btrfs-trim.service %{buildroot}%{_unitdir}
install -m 644 -D btrfs-balance.timer %{buildroot}%{_unitdir}
install -m 644 -D btrfs-defrag.timer %{buildroot}%{_unitdir}
install -m 644 -D btrfs-scrub.timer %{buildroot}%{_unitdir}
install -m 644 -D btrfs-trim.timer %{buildroot}%{_unitdir}
install -m 755 -d %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcbtrfsmaintenance-refresh

# zypp plugin
install -m 755 -d %{buildroot}%{_prefix}/lib/zypp/plugins/commit
install -m 755 -D btrfs-defrag-plugin.sh %{buildroot}%{_prefix}/lib/zypp/plugins/commit

# config
install -m 755 -d %{buildroot}%{_fillupdir}
install -m 644 -D sysconfig.btrfsmaintenance %{buildroot}%{_fillupdir}

%pre
# if the new service files don't exist, we migrate from
# old version with old script, remove cron symlinks
[ ! -f %{_unitdir}/btrfs-balance.timer -a -f %{_datadir}/%{name}/btrfsmaintenance-refresh-cron.sh ]  && %{_datadir}/%{name}/btrfsmaintenance-refresh-cron.sh uninstall
%service_add_pre btrfsmaintenance-refresh.service btrfsmaintenance-refresh.path btrfs-balance.service btrfs-balance.timer btrfs-defrag.service btrfs-defrag.timer btrfs-scrub.service btrfs-scrub.timer btrfs-trim.service btrfs-trim.timer

%post
%service_add_post btrfsmaintenance-refresh.service btrfsmaintenance-refresh.path btrfs-balance.service btrfs-balance.timer btrfs-defrag.service btrfs-defrag.timer btrfs-scrub.service btrfs-scrub.timer btrfs-trim.service btrfs-trim.timer
%{fillup_only btrfsmaintenance}

%preun
%service_del_preun btrfsmaintenance-refresh.service btrfsmaintenance-refresh.path btrfs-balance.service btrfs-balance.timer btrfs-defrag.service btrfs-defrag.timer btrfs-scrub.service btrfs-scrub.timer btrfs-trim.service btrfs-trim.timer

%postun
%service_del_postun btrfsmaintenance-refresh.service btrfsmaintenance-refresh.path btrfs-balance.service btrfs-balance.timer btrfs-defrag.service btrfs-defrag.timer btrfs-scrub.service btrfs-scrub.timer btrfs-trim.service btrfs-trim.timer

%files
%license COPYING
%doc README.md
%{_fillupdir}/sysconfig.btrfsmaintenance
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*
%dir %{_prefix}/lib/zypp/
%dir %{_prefix}/lib/zypp/plugins
%dir %{_prefix}/lib/zypp/plugins/commit
%{_prefix}/lib/zypp/plugins/commit/btrfs-defrag-plugin.sh
%{_unitdir}/btrfsmaintenance-refresh.path
%{_unitdir}/btrfsmaintenance-refresh.service
%{_unitdir}/btrfs-balance.service
%{_unitdir}/btrfs-defrag.service
%{_unitdir}/btrfs-scrub.service
%{_unitdir}/btrfs-trim.service
%{_unitdir}/btrfs-balance.timer
%{_unitdir}/btrfs-defrag.timer
%{_unitdir}/btrfs-scrub.timer
%{_unitdir}/btrfs-trim.timer
%{_sbindir}/rcbtrfsmaintenance-refresh

%changelog
* Wed Feb 10 2021 kukuk@suse.com
- Require libzypp plugin only if zypper is used (Required for e.g.
  image based systems).
* Wed Aug 19 2020 callumjfarmer13@gmail.com
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Wed Jul 29 2020 dsterba@suse.cz
- update to version 0.5
  - sysconfig:
  - change defaults of MUSAGE and DUSAGE for balance task to do less work,
    with a script to switch from existing unmodified defaults to new ones
  - document systemd.timer syntax
  - make balance, scrub, and trim mutually exclusive tasks
  - service file updates:
  - delete Install section
  - defrag-plugin:
  - switch to python3
  - add alternative shell implementation of the plugin
  - installation docs update
- Removed patches (upstream):
  - 0001-README-document-impact-of-balance-quota-groups.patch
  - 0002-sysconfig-reduce-default-balance-usage-thresholds-fa.patch
  - 0003-sysconfig-document-using-systemd.time-7-for-frequenc.patch
  - 0004-btrfsmaintenance-refresh-cron.sh-validate-periods-fo.patch
  - 0005-btrfs-defrag-plugin-remove-dependency-on-zypp-plugin.patch
* Tue Jun 11 2019 dsterba@suse.cz
- spec: fix typo in macro name
* Tue Jun 11 2019 dimstar@opensuse.org
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Tue Mar 12 2019 jeffm@suse.com
- Document and adjust balance thresholds and periods (FATE#325529 jsc#SLE-3188).
  * README: document impact of balance + quota groups
  * sysconfig: reduce default balance usage thresholds
  * sysconfig: document using systemd.time(7) for frequency of operations
  * btrfsmaintenance-refresh-cron.sh: validate periods for cron-based systems
- Remove python dependency (FATE#326736 jsc#SLE-4130).
  * btrfs-defrag-plugin: remove dependency on zypp-plugin-python
- Added patches:
  * 0001-README-document-impact-of-balance-quota-groups.patch
  * 0002-sysconfig-reduce-default-balance-usage-thresholds-fa.patch
  * 0003-sysconfig-document-using-systemd.time-7-for-frequenc.patch
  * 0004-btrfsmaintenance-refresh-cron.sh-validate-periods-fo.patch
  * 0005-btrfs-defrag-plugin-remove-dependency-on-zypp-plugin.patch
- Added source:
  * btrfs-defrag-plugin.sh
- Removed patch:
  * python3-support-bsc1070322.diff
* Mon Sep 24 2018 dsterba@suse.cz
- update to version 0.4.2
  - CVE-2018-14722: expand auto mountpoints in a safe way
  - btrfs-defrag: fix missing function to detect btrfs filesystems (#52)
  - btrfs-trim: more verbose fstrim output (#60)
  - dist-install: print information about timer unit installation (#58)
* Fri Apr 13 2018 lpechacek@suse.com
- In openSUSE the defrag plugin must explicitly refer to Python 3.
  (bsc#1070322)
- Added patch: python3-support-bsc1070322.diff
* Wed Mar 14 2018 dsterba@suse.cz
- update to version 0.4.1
  - defrag plugin: python2 and 3 compatibility
  - defrag plugin: target extent size lowered to 32MiB (#43)
  - shell compatibility fixes
  - systemd unit type fixes
- Removed patch: python3-support-bsc1070322.diff (upstream)
* Mon Mar 12 2018 kukuk@suse.de
- Add missing btrfsmaintenance-refresh.path [bsc#1084871]
- Use %%license [bsc#1082318]
* Mon Feb  5 2018 lpechacek@suse.com
- Move the defrag plugin over to Python 3. (bsc#1070322)
- Added patch: python3-support-bsc1070322.diff
* Sun Jan 14 2018 dsterba@suse.cz
- update to version 0.4
  - add support for systemd timers and use them by default; the alternative
    cron scripts are still present (#29, #36)
  - add automatic monitoring (via systemd.path) of the config file,
    no manual updates by btrfsmaintenance-refresh.service needed (#38)
  - fix RPM database path detection
  - spec file cleanups
  - documentation updates
- removed patches:
  - btrfsmaintenance-0.3.1-fix-rpm-db-path.patch (upstream)
  - btrfsmaintenance-switch-to-timer.patch (upstream)
  - pull-request-36.patch (upstream)
* Fri Dec 22 2017 antoine.belvire@opensuse.org
- Fix systemd timers enabled even if period is set to none:
  * Micro change in pull-request-36.patch (bsc#1075884)
- Clean spec file:
  * Removed support for suse_version <= 1210.
  * Removed call to btrfsmaintenance-refresh-cron.sh upon deletion
    (not needed anymore since we use systemd timers which are
    handled by macros).
  * Ran spec-cleaner.
* Sun Dec 17 2017 kukuk@suse.de
- Switch default of btrfsmaintenance-refresh.service to systemd-timer,
  too (btrfsmaintenance-switch-to-timer.patch) [bsc#1073204]
* Wed Dec  6 2017 kukuk@suse.de
- pull-request-36.patch: update patch
* Wed Dec  6 2017 kukuk@suse.de
- Don't call btrfsmaintenance-refresh-cron.sh in %%post, this is
  done already by the systemd macros
* Tue Dec  5 2017 kukuk@suse.com
- Add patch to use systemd timer instead of cron (pull-request-36.patch)
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Fri Nov 10 2017 antoine.belvire@opensuse.org
- Fix cron symlinks removal upon package upgrade (boo#904518):
  * The problem was in the preun section (in the old RPM).
  * This means the symlinks are removed by this update, but won't
    be by the next ones.
  * Please run 'systemctl start btrfsmaintenance-refresh' one more
    time to fix your symlinks.
* Tue Nov  7 2017 antoine.belvire@opensuse.org
- Add btrfsmaintenance-0.3.1-fix-rpm-db-path.patch:
  * Change RPM database path to /usr/lib/sysimage/rpm for
    Tumbleweed.
* Wed Jul  5 2017 lnussel@suse.de
- Require btrfsprogs (bsc#1047226)
* Thu Apr  6 2017 dsterba@suse.cz
- version 0.3.1
  - dist-install: fix installation paths, install functions
  - functions: fix syntax to be compatible with dash
  - spec: install functions file
* Mon Nov 14 2016 dsterba@suse.cz
- version 0.3
  - add syslog to logging targets
  - add none target (/dev/null)
  - autodetect btrfs filesystems for balance, scrub and trim
  - detect mixed blockgroups and use correct balance filters
  - fix uninstall rules
  - fix capturing entire output to the log
  - fix when cron files are symlinks
  - add generic installation script
  - doc updates: retention policy tuning
* Thu Mar  3 2016 dsterba@suse.cz
- version 0.2
  - updated documentation
  - support debian-like configuration paths
  - no hardcoded paths to external utilities
  - fixed logger name typos for 'journal' target
  - defrag fixes (sysconfig, find arguments)
* Wed Oct  7 2015 dsterba@suse.cz
- version 0.1.2
  - change default config for trim: off
  - journal loggin should work (fixed a typo)
* Sun Jul 12 2015 dsterba@suse.com
- version 0.1.1
  - fix typo and make journal logging target work
* Tue Nov 18 2014 dsterba@suse.cz
- cron refresh: remove bashism
- cron refresh: remove debugging messages
- post installation must create the cron links (bsc#904518)
- Removed patches:
  * btrfsmaintenance-0.1-fix-bashisms.patch
* Sat Nov 15 2014 ledest@gmail.com
- fix bashism in btrfsmaintenance-refresh-cron.sh script
- add patches:
  * btrfsmaintenance-0.1-fix-bashisms.patch
* Tue Oct 28 2014 dsterba@suse.cz
- add COPYING, README.md
- add config option to specify log target (stdout, or journal)
* Thu Oct  9 2014 dsterba@suse.cz
- clean spec
- add Url tag
* Thu Oct  9 2014 dsterba@suse.cz
- fix sysconfig file Path: tags
* Wed Sep 24 2014 dsterba@suse.cz
- initial import 0.1
